@@ -4,6 +4,8 @@ import os
 
 import config
 from insider.config import InsiderConfig
+from insider.port_config import PortConfig
+from insider.service_config import ServiceConfig
 import upnpc
 import port_mapper
 import dns
@@ -75,11 +77,11 @@ def get_insider(bin_path=default_bin_path, config_path=default_config_path, logs
     services_config_path = os.path.join(config_path, 'services.json')
     port_config_path = os.path.join(config_path, 'ports.json')
 
-    port_config = config.PortConfig(port_config_path)
+    port_config = PortConfig(port_config_path)
     upnpclient = upnpc.Upnpc()
     mapper = port_mapper.PortMapper(port_config, upnpclient)
     domain_config = config.DomainConfig(domain_config_path)
-    service_config = config.ServiceConfig(services_config_path)
+    service_config = ServiceConfig(services_config_path)
 
     dns_service = dns.Dns(
         insider_config.get_redirect_api_url(),
