@@ -18,7 +18,7 @@ class PortMapper:
         external_port = self.available("TCP")
         mapping = Port(local_port, external_port)
         self.upnpc.add(mapping.local_port, mapping.external_port)
-        self.port_config.add(mapping)
+        self.port_config.add_or_update(mapping)
         return mapping
 
     def remove(self, local_port):
@@ -52,6 +52,6 @@ class PortMapper:
                     self.upnpc.remove(port)
                 if first_external_port != mapping.external_port:
                     mapping.external_port = first_external_port
-                    self.port_config.update(mapping)
+                    self.port_config.add_or_update(mapping)
             else:
                 self.add(mapping.local_port)
\ No newline at end of file
